@@ -17,7 +17,7 @@ def _download_global_config(config_path: str) -> DataPipelinesConfig:
     config_path = add_suffix_to_git_template_path(config_path)
 
     with tempfile.TemporaryDirectory() as tmp:
-        copier.copy(config_path, tmp, quiet=True)
+        copier.run_auto(config_path, tmp, quiet=True)
         with open(pathlib.Path(tmp).joinpath("dp.yml")) as config_file:
             config = yaml.safe_load(config_file)
     return config
@@ -44,8 +44,8 @@ def init(config_path: Optional[str]) -> None:
     else:
         config = DEFAULT_GLOBAL_CONFIG
 
-    with open(ENV_CONFIGURATION_PATH, "w") as f:
-        yaml.dump(config, f, default_flow_style=False)
+    with open(ENV_CONFIGURATION_PATH, "w") as config_file:
+        yaml.dump(config, config_file, default_flow_style=False)
 
 
 @click.command(name="init", help="Configure the tool for the first time")
