@@ -1,6 +1,5 @@
 import click
 import copier
-from copier.config.objects import NoSrcPathError
 
 from data_pipelines_cli.cli_utils import echo_warning
 from data_pipelines_cli.errors import NotAProjectDirectoryError
@@ -16,8 +15,8 @@ def update(project_path: str, vcs_ref: str) -> None:
     :type vcs_ref: str
     """
     try:
-        copier.copy(dst_path=project_path, vcs_ref=vcs_ref, force=True)
-    except NoSrcPathError:
+        copier.run_auto(dst_path=project_path, vcs_ref=vcs_ref)
+    except ValueError:
         raise NotAProjectDirectoryError(project_path)
 
 
